Policy

Enum Policy 

pub enum Policy {
    Static(StaticPolicy),
    Linked(LinkedPolicy),
}
A Policy can be represented either as a static policy or a linked policy. A linked policy can be transformed into a static one, but information about the template id and which slots are linked would be lost.

Variants



Static(StaticPolicy)

Static policy, i.e. a policy with no slots



Linked(LinkedPolicy)

Linked policy, i.e. a policy with slots and their instantiation

Implementations

Source

impl Policy

pub fn body(&self) -> &Template

Get a reference to the body of the policy

pub fn new_id(&self, id: PolicyID) -> Policy

Clone this Policy with a new ID