#[non_exhaustive]pub enum PstConstructionError {
Show 15 variants
PolicyMissingLinkId(PolicyMissingLinkIdError),
ActionConstraintCannotHaveSlots(ActionConstraintCannotHaveSlotsError),
ExpectedTemplateWithSlots(ExpectedTemplateWithSlotsError),
WrongSlotPosition(WrongSlotPositionError),
DuplicateRecordKey(DuplicateRecordKeyError),
InvalidAnnotation(InvalidAnnotationError),
InvalidEntityUid(InvalidEntityUidError),
InvalidEntityType(InvalidEntityTypeError),
InvalidExpression(InvalidExpressionError),
UnknownFunction(UnknownFunctionError),
WrongArity(WrongArityError),
UnsupportedErrorNode(UnsupportedErrorNode),
ParsingFailed(ParsingFailedError),
LinkingFailed(LinkingError),
ContainsSlots(ContainsSlotError),
}Expand description
Errors that can occur during PST construction or conversion
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
PolicyMissingLinkId(PolicyMissingLinkIdError)
A policy is a linked policy but no link id has been provided
ActionConstraintCannotHaveSlots(ActionConstraintCannotHaveSlotsError)
Action constraints cannot contain template slots
ExpectedTemplateWithSlots(ExpectedTemplateWithSlotsError)
Expected a template with slots, but found a static policy
WrongSlotPosition(WrongSlotPositionError)
Slot occurs in the wrong position (e.g., principal slot in resource)
DuplicateRecordKey(DuplicateRecordKeyError)
Duplicate key found in a record literal
InvalidAnnotation(InvalidAnnotationError)
Invalid annotation in a policy or template
InvalidEntityUid(InvalidEntityUidError)
Invalid entity UID format or structure
InvalidEntityType(InvalidEntityTypeError)
Invalid entity type name
InvalidExpression(InvalidExpressionError)
A generic invalid expression error with a description
UnknownFunction(UnknownFunctionError)
Unknown function name (not a built-in or registered extension function)
WrongArity(WrongArityError)
Function called with wrong number of arguments
UnsupportedErrorNode(UnsupportedErrorNode)
Error nodes from parsing are not supported in PST conversion
ParsingFailed(ParsingFailedError)
A parsing error occurred, usually in names
LinkingFailed(LinkingError)
A linking error occurred.
ContainsSlots(ContainsSlotError)
Contains unexpected slots