pub struct Id(/* private fields */);Expand description
A validated Cedar identifier.
Wraps a SmolStr that has been checked to be a valid Cedar identifier
(not a reserved keyword, no special characters, etc.).
The only way to create an Id is through Id::new() (which validates
that the input is a valid identifier) or through conversion from other
validated identifier representations.
Accessing the inner string is free via as_str() or
into_smolstr().
let id = Id::new("userName").expect("valid identifier");
assert_eq!(id.as_str(), "userName");
// Reserved keywords are rejected:
assert!(Id::new("if").is_err());
assert!(Id::new("true").is_err());Implementations