pub struct Name {
pub id: Id,
pub namespace: Arc<Vec<Id>>,
}Expand description
A qualified name (e.g., Namespace::Type).
Represents entity types, action names, and other identifiers in Cedar. Names consist of a basename and optional namespace components.
// Unqualified: just a basename
User
Photo
// Qualified: namespace components followed by basename
MyApp::User
AWS::EC2::InstanceFields
id: IdBasename (the final component of the name)
namespace: Arc<Vec<Id>>Namespace components (empty for unqualified names)
Implementations
Sourceimpl Name
impl Name
Sourcepub fn unqualified(id: impl AsRef<str>) -> Result<Name, PstConstructionError>
pub fn unqualified(id: impl AsRef<str>) -> Result<Name, PstConstructionError>
Constructs an unqualified name. This is a convenience constructor that validates
that id is a legal Cedar identifier.
If you have an Id (which is AsRef<str>), you can infallibly construct the name
yourself.