pub struct UndeclaredActionsDescendantError { /* private fields */ }Expand description
Undeclared actions error: an action’s descendants references actions that are not declared in the schema. This can only occur when the schema was built directly, for example through the protobuf interface, but not when a name-resolution pass (when parsing) occurs. In the protobuf format, the hierarchy is inverted and descendants are declared, not parents.