ActionQueryRequest

Struct ActionQueryRequest 

pub struct ActionQueryRequest { /* private fields */ }
Available on crate feature tpe only.
Defines a PartialRequest which additionally leaves the action undefined, enabling queries listing what actions might be authorized.

See PolicySet::query_action for documentation and example usage.

This feature is experimental. For more information see https://github.com/cedar-policy/rfcs/blob/main/README.md#experimental-features

Implementations

Source

impl ActionQueryRequest

pub fn new( principal: PartialEntityUid, resource: PartialEntityUid, context: Option<Context>, schema: Schema, ) -> Result<Self, PartialRequestCreationError>

Construct an ActionQueryRequest.

Unlike PartialRequest::new, this constructor cannot validate the request because request validation requires knowing the specific action being authorized. Further, PolicySet::query_action cannot report request validation errors because it is expected that the principal, resource, and context will be invalid for many of the actions in the schema.