PrincipalQueryRequest

Struct PrincipalQueryRequest 

pub struct PrincipalQueryRequest(/* private fields */);
Available on crate feature tpe only.
Like PartialRequest but only principal can be unknown

Intended for use with PolicySet::query_principal.

This feature is experimental. For more information see https://github.com/cedar-policy/rfcs/blob/main/README.md#experimental-features

Implementations

Source

impl PrincipalQueryRequest

pub fn new( principal: EntityTypeName, action: EntityUid, resource: EntityUid, context: Context, schema: &Schema, ) -> Result<Self, PartialRequestCreationError>

Construct a valid PrincipalQueryRequest according to a Schema

pub fn to_request( &self, principal_id: EntityId, schema: Option<&Schema>, ) -> Result<Request, RequestValidationError>

Convert this to a Request by providing the principal EntityId

Even though the partial request was already validated in PrincipalQueryRequest::new, to ensure that the concrete request returned here is valid we still need to check the principal entity id. If the principal has an enum entity type, then its id must be one of the listed instances of that type.