pub enum EntitiesConsistencyError {
MissingEntity(MissingEntityError),
UnknownEntity(UnknownEntityError),
InconsistentEntity(EntityConsistencyError),
}Available on crate feature
tpe only.Expand description
Error thrown when checking the consistency between crate::tpe::entities::PartialEntities and
crate::entities::Entities
Variants
MissingEntity(MissingEntityError)
Error thrown when there is an entity missing in the concrete entities
UnknownEntity(UnknownEntityError)
Error thrown when concrete entities contain unknown entities
InconsistentEntity(EntityConsistencyError)
Error thrown when a concrete entity and a partial entity are inconsistent