pub enum JsonDeserializationError {
Concrete(JsonDeserializationError),
UnexpectedAction(UnexpectedActionError),
RestrictedExprEvaluation(EvaluationError),
}Available on crate feature
tpe only.Expand description
Error thrown when deserializing a crate::tpe::entities::PartialEntity
Variants
Concrete(JsonDeserializationError)
Error thrown when deserializing concrete components
UnexpectedAction(UnexpectedActionError)
Error thrown when encountered an action Actions are automatically inserted from a schema
RestrictedExprEvaluation(EvaluationError)
Error thrown when a restricted expression does not evaluate to a value