pub enum Policy {
Static(StaticPolicy),
Linked(LinkedPolicy),
}Expand description
A Policy can be represented either as a static policy or a linked policy. A linked policy can be transformed into a static one, but information about the template id and which slots are linked would be lost.
Variants
Static(StaticPolicy)
Static policy, i.e. a policy with no slots
Linked(LinkedPolicy)
Linked policy, i.e. a policy with slots and their instantiation
Implementations