#[non_exhaustive]pub struct LinkedPolicy { /* private fields */ }Expand description
A linked policy, i.e. a template with information to fill the slots and the id of the link.
To build a LinkedPolicy, you should use LinkedPolicy::new, which will validate that
the linked policy is provided values for all the slots in its body.
Implementations
Sourceimpl LinkedPolicy
impl LinkedPolicy
Sourcepub fn new(
template: Arc<Template>,
values: HashMap<SlotId, EntityUID>,
instance_id: PolicyID,
) -> Result<LinkedPolicy, LinkingError>
pub fn new( template: Arc<Template>, values: HashMap<SlotId, EntityUID>, instance_id: PolicyID, ) -> Result<LinkedPolicy, LinkingError>
Create a new LinkedPolicy from a template, slot values, and an instance id.
Returns an error if any slot in the template is not provided a value.
Sourcepub fn into_static_policy(&self) -> Result<StaticPolicy, PstConstructionError>
pub fn into_static_policy(&self) -> Result<StaticPolicy, PstConstructionError>
Get the static policy statement that this linked policy represents.
Loses the link between the template and the instantiation (the template is cloned
and then the slots are replaced by the values in vals and the id is changed
to instance_id)