PolicySet

Struct PolicySet 

pub struct PolicySet {
    pub templates: LinkedHashMap<PolicyID, Template>,
    pub policies: LinkedHashMap<PolicyID, StaticPolicy>,
    pub template_links: Vec<TemplateLink>,
}
A collection of Cedar policies, templates, and template links.

Use PolicySet to group related policies for conversion to the authorization engine’s internal representation via cedar_policy::PolicySet::from_pst().

let mut ps = PolicySet {
    templates: LinkedHashMap::new(),
    policies: LinkedHashMap::new(),
    template_links: vec![],
};
let template = Template::new(
    "p0", Effect::Permit,
    PrincipalConstraint::Any, ActionConstraint::Any, ResourceConstraint::Any,
);
ps.policies.insert(
    template.id.clone(),
    StaticPolicy::try_from(template).unwrap(),
);

Fields

templates: LinkedHashMap<PolicyID, Template>

Templates (policies with slots) keyed by template id.

policies: LinkedHashMap<PolicyID, StaticPolicy>

Static policies (no slots) keyed by policy id.

template_links: Vec<TemplateLink>

Links that instantiate templates with concrete entity UIDs.